"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isApplicationCommandDMInteraction = exports.isApplicationCommandGuildInteraction = exports.isDMInteraction = exports.isGuildInteraction = void 0;
/**
 * A type-guard check for guild interactions.
 * @param interaction The interaction to check against the
 * @returns A boolean that indicates if the interaction was received from a guild
 */
function isGuildInteraction(interaction) {
    return Reflect.has(interaction, 'guild_id');
}
exports.isGuildInteraction = isGuildInteraction;
/**
 * A type-guard check for DM interactions.
 * @param interaction The interaction to check against
 * @returns A boolean that indicates if the interaction was received from a direct message
 */
function isDMInteraction(interaction) {
    return !isGuildInteraction(interaction);
}
exports.isDMInteraction = isDMInteraction;
/**
 * A type-guard check for guild application command interactions.
 * @param interaction The interaction to check against
 * @returns A boolean that indicates if the command interaction was received from a guild
 */
function isApplicationCommandGuildInteraction(interaction) {
    return isGuildInteraction(interaction);
}
exports.isApplicationCommandGuildInteraction = isApplicationCommandGuildInteraction;
/**
 * A type-guard check for direct message application command interactions.
 * @param interaction The interaction to check against
 * @returns A boolean that indicates if the command interaction was received from a direct message
 */
function isApplicationCommandDMInteraction(interaction) {
    return !isGuildInteraction(interaction);
}
exports.isApplicationCommandDMInteraction = isApplicationCommandDMInteraction;
//# sourceMappingURL=v8.js.map